<?php

namespace Newage\Advertisements\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Newage\Advertisements\Interfaces\AdvertisementRepositoryInterface;

class AdvertisementPublicController extends BaseController
{
    // use AdvertisementWorkflow;

    /**
     * Constructor.
     *
     * @param type \Newage\Advertisement\Interfaces\AdvertisementRepositoryInterface $advertisement
     *
     * @return type
     */
    public function __construct(AdvertisementRepositoryInterface $advertisement)
    {
        $this->repository = $advertisement;
        parent::__construct();
    }

    /**
     * Show advertisement's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $advertisements = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$advertisements::$advertisement.names'))
            ->view('$advertisements::public.advertisement.index')
            ->data(compact('$advertisements'))
            ->output();
    }

    /**
     * Show advertisement's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $advertisements = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$advertisements::$advertisement.names'))
            ->view('$advertisements::public.advertisement.index')
            ->data(compact('$advertisements'))
            ->output();
    }

    /**
     * Show advertisement.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $advertisement = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$advertisement->name . trans('$advertisements::$advertisement.name'))
            ->view('$advertisements::public.advertisement.show')
            ->data(compact('$advertisement'))
            ->output();
    }

}
