<?php

namespace Newage\Advertisements\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Advertisements\Models\Advertisement;

class AdvertisementPolicy
{

    /**
     * Determine if the given user can view the advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Advertisement $advertisement)
    {
        if ($user->canDo('advertisements.advertisement.view') && $user->isAdmin()) {
            return true;
        }

        return $advertisement->user_id == user_id() && $advertisement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advertisements.advertisement.create');
    }

    /**
     * Determine if the given user can update the given advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Advertisement $advertisement)
    {
        if ($user->canDo('advertisements.advertisement.edit') && $user->isAdmin()) {
            return true;
        }

        return $advertisement->user_id == user_id() && $advertisement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Advertisement $advertisement)
    {
        return $advertisement->user_id == user_id() && $advertisement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Advertisement $advertisement)
    {
        if ($user->canDo('advertisements.advertisement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advertisement.
     *
     * @param UserPolicy $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Advertisement $advertisement)
    {
        if ($user->canDo('advertisements.advertisement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
