<?php

namespace Newage\Advertisements\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Advertisements\Models\AdvtHit;

class AdvtHitPolicy
{

    /**
     * Determine if the given user can view the advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function view(UserPolicy $user, AdvtHit $advt_hit)
    {
        if ($user->canDo('advertisements.advt_hit.view') && $user->isAdmin()) {
            return true;
        }

        return $advt_hit->user_id == user_id() && $advt_hit->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('advertisements.advt_hit.create');
    }

    /**
     * Determine if the given user can update the given advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function update(UserPolicy $user, AdvtHit $advt_hit)
    {
        if ($user->canDo('advertisements.advt_hit.edit') && $user->isAdmin()) {
            return true;
        }

        return $advt_hit->user_id == user_id() && $advt_hit->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AdvtHit $advt_hit)
    {
        return $advt_hit->user_id == user_id() && $advt_hit->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AdvtHit $advt_hit)
    {
        if ($user->canDo('advertisements.advt_hit.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advt_hit.
     *
     * @param UserPolicy $user
     * @param AdvtHit $advt_hit
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AdvtHit $advt_hit)
    {
        if ($user->canDo('advertisements.advt_hit.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
