<?php

namespace Newage\Advertisements\Providers;

use Illuminate\Support\ServiceProvider;

class AdvertisementsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'advertisements');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'advertisements');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('newage.advertisements', function ($app) {
            return $this->app->make('Newage\Advertisements\Advertisements');
        });

        // Bind Advertisement to repository
        $this->app->bind(
            'Newage\Advertisements\Interfaces\AdvertisementRepositoryInterface',
            \Newage\Advertisements\Repositories\Eloquent\AdvertisementRepository::class
        );
        // Bind AdvtHit to repository
        $this->app->bind(
            'Newage\Advertisements\Interfaces\AdvtHitRepositoryInterface',
            \Newage\Advertisements\Repositories\Eloquent\AdvtHitRepository::class
        );

        $this->app->register(\Newage\Advertisements\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Newage\Advertisements\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['newage.advertisements'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('newage/advertisements.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/advertisements')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/advertisements')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
