<?php

namespace Newage\Advertisements\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Newage\Advertisements\Models\Advertisements;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Newage\Advertisements\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/advertisements/advertisement/*')) {
            Route::bind('advertisement', function ($advertisement) {
                $advertisementrepo = $this->app->make('Newage\Advertisements\Interfaces\AdvertisementRepositoryInterface');
                return $advertisementrepo->findorNew($advertisement);
            });
        }

        if (Request::is('*/advertisements/advt_hit/*')) {
            Route::bind('advt_hit', function ($advt_hit) {
                $advt_hitrepo = $this->app->make('Newage\Advertisements\Interfaces\AdvtHitRepositoryInterface');
                return $advt_hitrepo->findorNew($advt_hit);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
